Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(258)

Unified Diff: runtime/vm/growable_array.h

Issue 296003013: - Reduce the number of Isolate::Current() calls. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/growable_array.h
===================================================================
--- runtime/vm/growable_array.h (revision 36483)
+++ runtime/vm/growable_array.h (working copy)
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Defines growable array classes, that differ where they are allocated:
// - GrowableArray: allocate on stack.
// - ZoneGrowableArray: allocated in the zone.
#ifndef VM_GROWABLE_ARRAY_H_
@@ -122,10 +122,12 @@
template<typename T>
class GrowableArray : public BaseGrowableArray<T, ValueObject> {
public:
+ GrowableArray(Isolate* isolate, intptr_t initial_capacity)
+ : BaseGrowableArray<T, ValueObject>(
+ initial_capacity, isolate->current_zone()) {}
explicit GrowableArray(intptr_t initial_capacity)
: BaseGrowableArray<T, ValueObject>(
- initial_capacity,
- Isolate::Current()->current_zone()) {}
+ initial_capacity, Isolate::Current()->current_zone()) {}
GrowableArray()
: BaseGrowableArray<T, ValueObject>(
Isolate::Current()->current_zone()) {}
@@ -135,6 +137,9 @@
template<typename T>
class ZoneGrowableArray : public BaseGrowableArray<T, ZoneAllocated> {
public:
+ ZoneGrowableArray(Isolate* isolate, intptr_t initial_capacity)
+ : BaseGrowableArray<T, ZoneAllocated>(
+ initial_capacity, isolate->current_zone()) {}
explicit ZoneGrowableArray(intptr_t initial_capacity)
: BaseGrowableArray<T, ZoneAllocated>(
initial_capacity,
@@ -2,7 +2,7 @@
// BSD-style license that can be found in the LICENSE file.
// Defines growable array classes, that differ where they are allocated:
-// - GrowableArray: allocate on stack.
+// - GrowableArray: allocated on stack.
// - ZoneGrowableArray: allocated in the zone.
#ifndef VM_GROWABLE_ARRAY_H_

Powered by Google App Engine
This is Rietveld 408576698